@@ -2,7 +2,7 @@
  *	pg_migrator.h
  */
 
-#define	PG_MIGRATOR_VERSION	"8.4.6"
+#define	PG_MIGRATOR_VERSION	"8.4.7"
 
 #include "postgres.h"
 
@@ -33,16 +33,6 @@
 #define MESSAGE_WIDTH		"60"
 
 #define OVERWRITE_MESSAGE	"  %-" MESSAGE_WIDTH "." MESSAGE_WIDTH "s\r"
-/*
- * Note: The C preprocessor stringify operator ('#') makes a string
- * from its argument, without macro expansion e.g. If "version" is
- * #define'd to be "4", then STRINGIFY_AWE(version) will return the
- * string "version", not "4" To expand "version" to its value before
- * making the string, use STRINGIFY(version) instead
- */
-#define STRINGIFY_ARGUMENT_WITHOUT_EXPANSION(s) #s
-#define STRINGIFY(s)	STRINGIFY_ARGUMENT_WITHOUT_EXPANSION(s)
-
 #define GET_MAJOR_VERSION(v)	((v) / 100)
 
 #ifndef WIN32
@@ -209,7 +199,6 @@ typedef struct
 	char	   *pg_version_str;	/* string PG_VERSION of cluster */
 	Oid			pg_database_oid;		/* OID of pg_database relation */
 	char	   *libpath;	/* pathname for cluster's pkglibdir */
-	uint32		autovacuum_freeze_max_age; /* must match old/new server */
 	/* EDB AS is PG 8.2 with 8.3 enhancements backpatched. */
 	bool		is_edb_as;	/* EnterpriseDB's Postgres Plus Advanced Server? */
 } ClusterInfo;
@@ -254,7 +243,7 @@ char		scandir_file_pattern[MAX_STRING + 1];
 
 /* controldata.c */
 
-void get_control_data(migratorContext *ctx, ClusterInfo *cluster);
+void get_control_data(migratorContext *ctx, ClusterInfo *cluster, bool live_check);
 void check_control_data(migratorContext *ctx, ControlData *oldctrl,
 				   ControlData *newctrl);
 void set_locale_and_encoding(migratorContext *ctx, Cluster whichCluster);
@@ -363,7 +352,6 @@ void 		start_postmaster(migratorContext *ctx, Cluster whichCluster, bool quiet);
 void		stop_postmaster(migratorContext *ctx, bool fast, bool quiet);
 uint32		get_postgres_version(migratorContext *ctx, char **verstr,
 								 Cluster whichCluster);
-void		get_autovacuum_freeze_max_age(migratorContext *ctx, Cluster whichCluster);
 void		check_for_libpq_envvars(migratorContext *ctx);
 
 
@@ -401,9 +389,9 @@ void		v8_4_populate_pg_largeobject_metadata(migratorContext *ctx,
 							bool check_mode, Cluster whichCluster);
 char 		*v8_3_create_sequence_script(migratorContext *ctx,
 							Cluster whichCluster);
-void		check_for_composite_types(migratorContext *ctx,
+void		v_8_4_check_for_composite_types(migratorContext *ctx,
 							Cluster whichCluster);
-void		check_for_array_types(migratorContext *ctx,
+void		v_8_4_check_for_array_types(migratorContext *ctx,
 							Cluster whichCluster);
-void		check_for_enum_types(migratorContext *ctx,
+void		v_8_4_check_for_enum_types(migratorContext *ctx,
 							Cluster whichCluster);
