@@ -154,35 +154,6 @@ get_postgres_version(migratorContext *ctx, char **verstr, Cluster whichCluster)
 }
 
 
-/*
- * get_autovacuum_freeze_max_age()
- *
- *	Retrieves the autovacuum_freeze_max_age to make sure old/new are the same.
- */
-void
-get_autovacuum_freeze_max_age(migratorContext *ctx, Cluster whichCluster)
-{
-	PGconn	   *conn = connectToServer(ctx, "template1", whichCluster);
-	PGresult   *res;
-
-	prep_status(ctx, "Getting autovacuum_freeze_max_age");
-
-	res = executeQueryOrDie(ctx, conn,
-							  "SELECT setting "
-							  "FROM   pg_catalog.pg_settings "
-							  "WHERE  name = 'autovacuum_freeze_max_age';");
-	if (whichCluster == CLUSTER_OLD)
-		ctx->old.autovacuum_freeze_max_age = (uint32) atol(PQgetvalue(res, 0, 0));
-	else
-		ctx->new.autovacuum_freeze_max_age = (uint32) atol(PQgetvalue(res, 0, 0));
-
-	PQclear(res);
-	PQfinish(conn);
-
-	check_ok(ctx);
-}
-
-
 /*
  * start_postmaster()
  *
@@ -214,7 +185,9 @@ start_postmaster(migratorContext *ctx, Cluster whichCluster, bool quiet)
 	if (!quiet)
 		prep_status(ctx, "Starting postmaster to service %s cluster\n", clusterName);
 	/* use -l for Win32 */
-	sprintf(cmd, SYSTEMQUOTE "\"%s/pg_ctl\" -l \"%s\" -D \"%s\" -o \"-p %d -c autovacuum=off\" start >> \"%s\" 2>&1" SYSTEMQUOTE,
+	sprintf(cmd, SYSTEMQUOTE "\"%s/pg_ctl\" -l \"%s\" -D \"%s\" "
+				"-o \"-p %d -c autovacuum=off -c autovacuum_freeze_max_age=2000000000\" "
+				"start >> \"%s\" 2>&1" SYSTEMQUOTE,
 				bindir, ctx->logfile, datadir, port, ctx->logfile);
 	exec_prog(ctx, true, "%s", cmd);
 
